@@ -1,5 +1,5 @@
 package Selenium::Remote::Driver;
-$Selenium::Remote::Driver::VERSION = '0.1801';
+$Selenium::Remote::Driver::VERSION = '0.19';
 # ABSTRACT: Perl Client for Selenium Remote Driver
 
 use Moo;
@@ -140,7 +140,21 @@ has 'proxy' => (
 
 has 'extra_capabilities' => (
     is      => 'rw',
-    default => sub { {} },
+    default => sub { {} }
+);
+
+has 'firefox_profile' => (
+    is => 'rw',
+    coerce => sub {
+        my $profile = shift;
+        unless (Scalar::Util::blessed($profile)
+          && $profile->isa('Selenium::Remote::Driver::Firefox::Profile')) {
+            croak "firefox_profile should be a Selenium::Remote::Driver::Firefox::Profile\n";
+        }
+
+        return $profile->_encode;
+    },
+    predicate => 'has_firefox_profile'
 );
 
 sub BUILD {
@@ -221,6 +235,11 @@ sub new_session {
         $args->{desiredCapabilities}->{proxy} = $self->proxy;
     }
 
+    if ($args->{desiredCapabilities}->{browserName} =~ /firefox/i
+        && $self->has_firefox_profile) {
+        $args->{desiredCapabilities}->{firefox_profile} = $self->firefox_profile;
+    }
+
     # command => 'newSession' to fool the tests of commands implemented
     # TODO: rewrite the testing better, this is so fragile.
     my $resp = $self->remote_conn->request(
@@ -1020,7 +1039,7 @@ Selenium::Remote::Driver - Perl Client for Selenium Remote Driver
 
 =head1 VERSION
 
-version 0.1801
+version 0.19
 
 =head1 SYNOPSIS
 
